@@ -12,14 +12,15 @@
 /// @author Emanuele Danovaro
 /// @date   August 2019
 
-#ifndef fdb5_Store_H
-#define fdb5_Store_H
+#pragma once
 
+#include "eckit/distributed/Transport.h"
 #include "eckit/filesystem/URI.h"
 #include "eckit/io/DataHandle.h"
 
+#include "fdb5/api/helpers/MoveIterator.h"
 #include "fdb5/config/Config.h"
-#include "fdb5/database/DB.h"
+#include "fdb5/database/Catalogue.h"
 #include "fdb5/database/Field.h"
 #include "fdb5/database/FieldLocation.h"
 #include "fdb5/database/Key.h"
@@ -29,12 +30,14 @@ namespace fdb5 {
 class Store {
 public:
 
-    Store(const Schema& schema) : schema_(schema) {}
+    Store() {}
 
     virtual ~Store() {}
 
     virtual eckit::DataHandle* retrieve(Field& field) const = 0;
-    virtual std::unique_ptr<FieldLocation> archive(const Key &key, const void *data, eckit::Length length) = 0;
+//    virtual void archive(const Key& key, const void *data, eckit::Length length, void(*catalogue_archive)(std::unique_ptr<FieldLocation> fieldLocation)) = 0;
+    virtual void archive(const Key& key, const void *data, eckit::Length length, std::function<void(const std::unique_ptr<FieldLocation> fieldLocation)> catalogue_archive);
+    virtual std::unique_ptr<FieldLocation> archive(const Key& key, const void *data, eckit::Length length);
 
     virtual void remove(const eckit::URI& uri, std::ostream& logAlways, std::ostream& logVerbose, bool doit = true) const = 0;
 
@@ -51,13 +54,11 @@ public:
     virtual void checkUID() const = 0;
 
     virtual bool canMoveTo(const Key& key, const Config& config, const eckit::URI& dest) const;
-    virtual void moveTo(const Key& key, const Config& config, const eckit::URI& dest, bool mpi, int threads) const { NOTIMP; }
+    virtual void moveTo(const Key& key, const Config& config, const eckit::URI& dest, eckit::Queue<MoveElement>& queue) const { NOTIMP; }
     virtual void remove(const Key& key) const { NOTIMP; }
 
     virtual eckit::URI uri() const = 0;
-
-protected: // members
-    const Schema& schema_;  //<< schema is owned by catalogue which always outlives the store
+    
 };
 
 
@@ -69,14 +70,14 @@ class StoreBuilderBase {
 public:
     StoreBuilderBase(const std::string&);
     virtual ~StoreBuilderBase();
-    virtual std::unique_ptr<Store> make(const Schema& schema, const Key& key, const Config& config) = 0;
-    virtual std::unique_ptr<Store> make(const Schema& schema, const eckit::URI& uri, const Config& config) = 0;
+    virtual std::unique_ptr<Store> make(const Key& key, const Config& config) = 0;
+    virtual std::unique_ptr<Store> make(const eckit::URI& uri, const Config& config) = 0;
 };
 
 template <class T>
 class StoreBuilder : public StoreBuilderBase {
-    virtual std::unique_ptr<Store> make(const Schema& schema, const Key& key, const Config& config) override { return std::unique_ptr<T>(new T(schema, key, config)); }
-    virtual std::unique_ptr<Store> make(const Schema& schema, const eckit::URI& uri, const Config& config) override { return std::unique_ptr<T>(new T(schema, uri, config)); }
+    virtual std::unique_ptr<Store> make(const Key& key, const Config& config) override { return std::unique_ptr<T>(new T(key, config)); }
+    virtual std::unique_ptr<Store> make(const eckit::URI& uri, const Config& config) override { return std::unique_ptr<T>(new T(uri, config)); }
 
 public:
     StoreBuilder(const std::string& name) : StoreBuilderBase(name) {}
@@ -93,17 +94,15 @@ public:
     bool has(const std::string& name);
     void list(std::ostream&);
 
-    /// @param schema    the schema read by the catalog
     /// @param key       the user-specified key
     /// @param config    the fdb config
     /// @returns         store built by specified builder
-    std::unique_ptr<Store> build(const Schema& schema, const Key& key, const Config& config);
+    std::unique_ptr<Store> build(const Key& key, const Config& config);
 
-    /// @param schema    the schema read by the catalog
     /// @param uri       search uri
     /// @param config    the fdb config
     /// @returns         store built by specified builder
-    std::unique_ptr<Store> build(const Schema& schema, const eckit::URI& uri, const Config& config);
+    std::unique_ptr<Store> build(const eckit::URI& uri, const Config& config);
 
 private:
     StoreFactory();
@@ -113,4 +112,3 @@ private:
 };
 
 }
-#endif  // fdb5_Store_H
