@@ -25,11 +25,12 @@ namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-class MatchValue : public Matcher {
+class MatchValue : public Matcher{
 
 public: // methods
 
     MatchValue(const std::string &value);
+    MatchValue(eckit::Stream& s);
 
     virtual ~MatchValue() override;
 
@@ -37,12 +38,20 @@ public: // methods
 
     virtual void dump(std::ostream &s, const std::string &keyword, const TypesRegistry &registry) const override;
 
+	const eckit::ReanimatorBase& reanimator() const override { return reanimator_; }
+	static const eckit::ClassSpec&  classSpec() { return classSpec_; }
+
 private: // methods
 
+    void encode(eckit::Stream&) const override;
+
     virtual void print( std::ostream &out ) const override;
 
 private: // members
 
+    static eckit::ClassSpec classSpec_;
+    static eckit::Reanimator<MatchValue> reanimator_;
+
     std::string value_;
 
 };
